@@ -409,12 +409,14 @@ class AutoMapperDataTypeBase:
 
     def sanitize(
         self: _TAutoMapperDataType,
+        pattern: str = r"[^\w\r\n\t _.,!\"'/$-]",
         replacement: str = " "
     ) -> _TAutoMapperDataType:
         """
         Replaces all "non-normal" characters with specified replacement
 
-        We're using the FHIR definition of valid string
+        By default, We're using the FHIR definition of valid string
+        (except /S does not seem to work properly in Spark)
         https://www.hl7.org/fhir/datatypes.html#string
         Valid characters are (regex='[ \r\n\t\\S]'):
         \\S - Any character that is not a whitespace character
@@ -423,23 +425,18 @@ class AutoMapperDataTypeBase:
         \n - line feed
         \t - tab
 
+        :param pattern: regex pattern of characters to replace
         :param replacement: (Optional) string to replace with.  Defaults to space.
         :return: a regex_replace automapper type
         """
 
         from spark_auto_mapper.data_types.regex_replace import AutoMapperRegExReplaceDataType
 
-        # https://www.hl7.org/fhir/datatypes.html#string
-        # So we replace any character that is not normal per our definition above
-        not_normal_characters: str = r"[^ \r\n\t\S]"
-
         # cast it to the inner type so type checking is happy
         # noinspection Mypy
         return cast(
             _TAutoMapperDataType,
             AutoMapperRegExReplaceDataType(
-                column=self,
-                pattern=not_normal_characters,
-                replacement=replacement
+                column=self, pattern=pattern, replacement=replacement
             )
         )
